<template>
    <div class="search-panel">
        <el-form ref="form" :model="form" label-width="90px" class="search-form">
            <el-form-item label="企业名称：" size="mini" class="search-panel-item">
                <el-select style="width: 100%" v-model="form.eventName" @change="handlePipelineType"
                           :popper-class="'select-down'">
                    <el-option
                            v-for="item in form.eventNameList"
                            :key="item.code"
                            :label="item.name"
                            :value="item.name">
                    </el-option>
                </el-select>
            </el-form-item>
            <el-form-item label="资源环境：" size="mini" class="search-panel-item">
                <el-select style="width: 100%" v-model="form.pipelineType" @change="handlePipelineType"
                           :popper-class="'select-down'">
                    <el-option
                            v-for="item in items"
                            :key="item.code"
                            :label="item.name"
                            :value="item.name">
                    </el-option>
                </el-select>
            </el-form-item>
            <el-form-item :label="form.pipelineType+'：'" size="mini">
                <el-select style="width: 100%" v-model="form.dataType" value-key="code"
                           :popper-class="'select-down'" @change="handleDataType">
                    <el-option
                            v-for="item in subItems"
                            :key="item.code"
                            :label="item.name"
                            :value="item.name">
                    </el-option>
                </el-select>
            </el-form-item>
            <div class="rightButtonSearch">
                <el-input v-model="form.keyword" size="mini" placeholder="在此输入关键字搜索"></el-input>
                <el-button class="el-icon-search" @click="handleSearch"></el-button>
            </div>
        </el-form>
        <el-scrollbar style="height:286.22px">
            <div class="environmental-risk-list" v-for="(item,index) in list" :key="index"
                 :class="activeNum===index?'hover':''" @click="handleLocation(item,index)">
                <img class="state" :src="getImgSrc()" style="background: none"/>
                <h3>资源类型:{{item.properties.adminzonename}}</h3>
                <h5>资源名称:{{item.properties.type}}</h5>
                <p>负责人:<span>{{item.properties.resperson}}</span></p>
                <p>电话:<span>{{item.properties.telephone}}</span></p>
            </div>
        </el-scrollbar>
    </div>
</template>

<script>
// import { LayerEntEmer } from '../../../../../conf/layers/LayerEntEmer'
import WfsHelper from '@components/helpers/WfsHelper'
import AjaxUtils from '@utils/AjaxUtils'

export default {
  name: 'ResourcesQuery',
  data () {
    return {
      form: {
        eventName: '',
        pipelineType: '资源类型',
        dataType: '',
        keyword: '',
        eventNameList: [
          { name: '金陵石化' },
          { name: '南京化学' }
        ]
      },
      activeNum: -1,
      list: [],
      // items: [LayerEntEmer],
      items: [{ name: '应急资源' }, { name: '周边环境' }],
      // subItems: LayerEntEmer.layers,
      subItems: [{ name: '全部资源' }, { name: '应急物资' }, { name: '应急车辆(船)' }, { name: '应急队伍(含消防单位)' }],
      subItemsT: [{ name: '全部环境' }, { name: '医院' }, { name: '学校' }, { name: '水体' }, { name: '自然保护区' }, { name: '敏感目标' }],
      WfsHelper: null
    }
  },
  mounted () {
    this.wfsHelper = new WfsHelper()
  },
  methods: {
    getImgSrc () {
      const icon = this.form.dataType.icon
      return icon ? 'assets/images/map/' + icon : ''
    },
    handlePipelineType (val) {
      console.log(val)
      this.list = []
      for (let i = 0; i < this.items.length; i++) {
        const item = this.items[i].name
        if (val === item.name) {
          this.subItems = item
          return
        }
      }
      // console.log('item')
      if (this.form.pipelineType === '应急资源') {
        this.form.pipelineType = '资源类型'
      }
      if (this.form.pipelineType === '周边环境') {
        this.subItems = this.subItemsT
      }
    },
    handleDataType (val) {
      console.log(val)
      this.list = []
    },
    async handleSearch () {
      this.list = []
      this.wfsHelper.clearFilter()
      // todo 现在企业应急还没区分开类型，后面改
      // this.wfsHelper.setTypeName([this.form.dataType.typeName])
      this.wfsHelper.setTypeName(['sewer:emergency'])
      if (this.form.dataType) {
        if (this.form.dataType === '全部环境' || this.form.dataType === '全部资源' || this.form.dataType === '') {

        } else {
          this.wfsHelper.addEquals('type', '\'' + this.form.dataType + '\'')
        }
      }
      if (this.form.keyword) {
        this.wfsHelper.addLike('name', this.form.keyword)
      }
      const res = await AjaxUtils.GetDataAsynByUrl(this.wfsHelper.getUrl(), {})
      console.log(res)
      if (res instanceof Object && Object.prototype.hasOwnProperty.call(res, 'features')) {
        this.list = res.features
      }
    },
    handleLocation (val, index) {
      this.activeNum = index
      window.map.flyTo([val.properties.y, val.properties.x], 15)
    }
  }
}
</script>

<style lang="less" scoped>

</style>
